<?php

namespace Drupal\save_continue\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

/**
 * Class SettingsForm.
 *
 * @package Drupal\save_edit\Form
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'save_continue.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'save_continue_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('save_continue.settings');
    $weights_range = range(-10, 10);
    $weights = array_combine($weights_range, $weights_range);

    $form['button_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Text to use for Save & Continue button'),
      '#description' => $this->t('This is the default text that will be used for the button at the bottom of the node form.<br>It would be best to use familiar terms like "<strong>Save &amp; Edit</strong>" or "<strong>Apply</strong>" so that users can easily understand the feature/function related to this option.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('button_value'),
    ];
    $form['button_weight'] = [
      '#type' => 'select',
      '#title' => $this->t('Save & Continue Button Weight'),
      '#description' => $this->t('You can adjust the horizontal positioning in the button section (or vertical positioning when using the dropbutton setting).'),
      '#options' => $weights,
      '#default_value' => $config->get('button_weight'),
    ];
    $form['dropbutton'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Integrate into dropbutton'),
      '#description' => $this->t('This setting will insert the Save &amp; Continue button into the save dropbutton.'),
      '#default_value' => $config->get('dropbutton'),
    ];

    $node_types = NodeType::loadMultiple();
    $keyed_node_types = [];
    foreach ($node_types as $content_type) {
      $keyed_node_types[$content_type->id()] = $content_type->label();
    }
    $default_value_node_types = $config->get('node_types');
    $form['node_types'] = [
      '#type' => 'checkboxes',
      '#options' => $keyed_node_types,
      '#title' => $this->t('Node types'),
      '#description' => $this->t('Set the node types you want to display links for.'),
      '#default_value' => isset($default_value_node_types) ? $default_value_node_types : [],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('save_continue.settings')
      ->set('button_value', $form_state->getValue('button_value'))
      ->set('button_weight', $form_state->getValue('button_weight'))
      ->set('dropbutton', $form_state->getValue('dropbutton'))
      ->set('node_types', $form_state->getValue('node_types'))
      ->save();
  }

}
